/**
 * Classe para trabalhar melhor com bytes
 * A classe usa Uint8Array com uma posição
 *
 * @export
 * @class Byte
 */
export declare class Byte {
    private _byte;
    /**
     * Creates an instance of Byte.
     * @param {number} valor
     * @memberof Byte
     */
    constructor(valor: number);
    /**
     * Retorna uma nova instancia de Byte a partir de um Numero
     * @param n Numero para construir o byte
     */
    static from(n: number): Byte;
    /**
     * Retorna o valor do byte salvo
     *
     * @memberof Byte
     */
    get value(): number;
    /**
     * Define um valor novo para o byte
     *
     * @memberof Byte
     */
    set value(valor: number);
    /**
     * Define a a posição de uma lista de bits de um byte como LOW ou HIGH e retorna o valor do Byte atualizado
     *
     * @param position Posição do bit que sera alterada
     * @param value Altura do Bit, True = High, False = Low
     */
    setBits(bits: Array<{
        position: number;
        value: boolean;
    }>): number;
    /**
     * Define a uma posicao do byte como LOW ou HIGH e retorna o valor atualizado
     *
     * @param position Posição do bit que sera alterada
     * @param value Altura do Bit, True = High, False = Low
     */
    setBit(pos: number, value: boolean): number;
    /**
     * Define a uma posicao do byte como HIGH e retorna o valor atualizado
     * @param position Posição do bit que sera alterada para Low
     */
    setBitHigh(position: number): number;
    /**
     * Define a uma posicao do byte como LOW e retorna o valor atualizado
     * @param position Posição do bit que sera alterada para High
     */
    setBitLow(position: number): number;
    /**
     *
     * @param position Posição do bit que sera lida
     */
    readBit(position: number): boolean;
}
